`timescale 1ns / 1ps

module AD7606C_UART_parallel(
	Clk_50,
	Reset_n,
	Rs232_Tx,
	Rs232_Rx,
	
	ad7606_cs_n_o,   
	ad7606_rd_n_o, 
	ad7606_wr_n_o,
	ad7606_busy_i,   
	ad7606_db_i,     
	ad7606_os_o,     
	ad7606_reset_o,  
	ad7606_convst_o
);
    
	input  wire 		 Clk_50;
	input  wire 		 Reset_n;

	output wire        Rs232_Tx;
	input  wire 		 Rs232_Rx;
    
	output wire        ad7606_cs_n_o;         
	output wire        ad7606_rd_n_o;           
	output wire        ad7606_wr_n_o;       
	input  wire        ad7606_busy_i;         
	inout 		[15:0] ad7606_db_i;           
	output wire [2:0]  ad7606_os_o;           
	output wire        ad7606_reset_o;        
	output wire        ad7606_convst_o;   

    wire fifowrreq;
    wire [15:0]fifowrdata;
    wire [7:0]uart_tx_data;
    wire uart_send_en;
    wire uart_tx_done;       
    wire key_flag;
    wire key_state; 
    wire fifordempty;
    wire fifordreq;
    wire [15:0]fiforddata;
    
    wire [7:0]rx_data;
    wire rx_done;
    
    wire [7:0]ChannelSel;
    wire [15:0]DataNum;
    wire [31:0] ADC_Speed_Set; 
    wire [31:0]ADC_soft_modle;
    
    wire [7:0]cmd_addr;
    wire [31:0]cmd_data;
    wire cmdvalid;    
    
    wire RestartReq;
    wire [7:0]adc_data_flag;
    wire [15:0]adc_data_mult_ch; 
	 
	 wire Clk; ////// 100mhz

  clk_wiz_0 pll_100mhz
   (
    // Clock out ports
    .clk_out1(Clk),     // output clk_out1
    // Status and control signals
    .resetn(Reset_n), // input resetn
    .locked(),       // output locked
   // Clock in ports
    .clk_in1(Clk_50));      // input clk_in1

	 
	//AD7606ģ 
    ad7606C_soft_driver ad7606C_soft_driver(
        .Clk(Clk),
        .Reset_n(Reset_n),
        .Go(1),
        .Speed_Set(ADC_Speed_Set),
        .ADC_soft_modle(ADC_soft_modle),
        .RestartReq(RestartReq),
        .DataNum(DataNum),
        .Conv_Done(),
        .ad7606_cs_n_o(ad7606_cs_n_o), 
        .ad7606_rd_n_o(ad7606_rd_n_o), 
        .ad7606_wr_n_o(ad7606_wr_n_o), 
        .ad7606_busy_i(ad7606_busy_i), 
        .ad7606_db_i(ad7606_db_i), 
        .ad7606_os_o(ad7606_os_o), 
        .ad7606_reset_o(ad7606_reset_o), 
        .ad7606_convst_o(ad7606_convst_o), 
		.data_flag(adc_data_flag),
		.data_mult_ch(adc_data_mult_ch),
        .data1(),
        .data2(), 
        .data3(), 
        .data4(), 
        .data5(), 
        .data6(), 
        .data7(), 
        .data8()
    );	


fifo_generator_0 fifo_generator_0 (
  .rst(~Reset_n),                  // input wire rst
  .wr_clk(Clk),            // input wire wr_clk
  .rd_clk(Clk_50),            // input wire rd_clk
  .din(fifowrdata),                  // input wire [15 : 0] din
  .wr_en(fifowrreq),              // input wire wr_en
  .rd_en(fifordreq),              // input wire rd_en
  .dout(fiforddata),                // output wire [15 : 0] dout
  .full(),                // output wire full
  .empty(fifordempty),              // output wire empty
  .wr_rst_busy(),  // output wire wr_rst_busy
  .rd_rst_busy()  // output wire rd_rst_busy
);
	 
    
    adc_write_ctrl adc_write_ctrl(
        .Clk(Clk),
        .Reset_n(Reset_n),
        .DataNum(DataNum),
        .RestartReq(RestartReq),
        .ChannelSel(ChannelSel),
        .fifowrreq(fifowrreq),
        .fifowrdata(fifowrdata),
        .fifowrfull(),
        .adc_data_flag(adc_data_flag),
        .adc_data_mult_ch(adc_data_mult_ch)
    );

    uart_byte_tx uart_byte_tx(
        .Clk(Clk_50),       //50Mʱ
        .Rst_n(Reset_n),     //ģ鸴λ
        .data_byte(uart_tx_data), //8bit
        .send_en(uart_send_en),   //ʹ
        .baud_set(4),  //
        .Rs232_Tx(Rs232_Tx),  //Rs232ź
        .Tx_Done(uart_tx_done),   //һηɱ־
        .uart_state() //״̬
    );
    
    uart_send_ctrl uart_send_ctrl(
        .Clk(Clk_50),
        .Reset_n(Reset_n),
        .uart_tx_data(uart_tx_data),
        .uart_send_en(uart_send_en),
        .uart_tx_done(uart_tx_done),
        .fifordempty(fifordempty),
        .fifordreq(fifordreq),
        .fiforddata(fiforddata)
    );
    
    uart_cmd uart_cmd(
        .Clk(Clk_50),
        .Reset_n(Reset_n),
        .rx_data(rx_data),
        .rx_done(rx_done),
        .address(cmd_addr),
        .data(cmd_data),
        .cmdvalid(cmdvalid)
    );
    
    uart_byte_rx uart_byte_rx(
        .Clk(Clk_50),
        .Reset_n(Reset_n),
        .Baud_Set(4),
        .uart_rx(Rs232_Rx),
        .Data(rx_data),
        .Rx_Done(rx_done)  
    ); 


    cmd_ctrl cmd_ctrl(
       .Clk(Clk_50),
       .Reset_n(Reset_n),
       .cmd_data(cmd_data),
       .cmd_addr(cmd_addr),
       .cmdvalid(cmdvalid),
       .RestartReq(RestartReq),
       .ChannelSel(ChannelSel),
       .DataNum(DataNum),
	   .ADC_soft_modle(ADC_soft_modle),
       .ADC_Speed_Set(ADC_Speed_Set)
	);

endmodule

